==> ejc-budgetmanage-impl-3.0.0-20220330.112743-39-sources.jar: com/ejianc/business/bedget/vo/SubpackagetotalVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包施工图预算汇总
 * 
 * @author generator
 * 
 */
public class SubpackagetotalVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long contract; // 合同
    private java.lang.String contractName; // 合同名称
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String section; // 区段
    private java.lang.String subtitleCode; // 子目编码
    private java.lang.String subtitleName; // 子目名称
    private java.lang.String subtitleFeature; // 子目特征描述
    private java.math.BigDecimal artificialTotal; // 人工费
    private java.math.BigDecimal materialsTotal; // 材料费
    private java.math.BigDecimal mechanicalTotal; // 机械费
    private java.math.BigDecimal enterpriseManageTotal; // 企业管理费
    private java.math.BigDecimal profitsTotal; // 利润
    private java.math.BigDecimal feesTotal; // 规费
    private java.math.BigDecimal taxTotal; // 税金
    private java.math.BigDecimal comprehensiveTotal; // 合价（元）
    private java.math.BigDecimal excludingTaxTotal; // 除税合价
    private java.math.BigDecimal includingTaxTotal; // 含税合价
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 区段
     */
    public java.lang.String getSection() {
        return section;
    }

    /**
     * 区段
     */
    public void setSection(java.lang.String section) {
        this.section = section;
    }
    /**
     * 子目编码
     */
    public java.lang.String getSubtitleCode() {
        return subtitleCode;
    }

    /**
     * 子目编码
     */
    public void setSubtitleCode(java.lang.String subtitleCode) {
        this.subtitleCode = subtitleCode;
    }
    /**
     * 子目名称
     */
    public java.lang.String getSubtitleName() {
        return subtitleName;
    }

    /**
     * 子目名称
     */
    public void setSubtitleName(java.lang.String subtitleName) {
        this.subtitleName = subtitleName;
    }
    /**
     * 子目特征描述
     */
    public java.lang.String getSubtitleFeature() {
        return subtitleFeature;
    }

    /**
     * 子目特征描述
     */
    public void setSubtitleFeature(java.lang.String subtitleFeature) {
        this.subtitleFeature = subtitleFeature;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getArtificialTotal() {
        return artificialTotal;
    }

    /**
     * 人工费
     */
    public void setArtificialTotal(java.math.BigDecimal artificialTotal) {
        this.artificialTotal = artificialTotal;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialsTotal() {
        return materialsTotal;
    }

    /**
     * 材料费
     */
    public void setMaterialsTotal(java.math.BigDecimal materialsTotal) {
        this.materialsTotal = materialsTotal;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalTotal() {
        return mechanicalTotal;
    }

    /**
     * 机械费
     */
    public void setMechanicalTotal(java.math.BigDecimal mechanicalTotal) {
        this.mechanicalTotal = mechanicalTotal;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getEnterpriseManageTotal() {
        return enterpriseManageTotal;
    }

    /**
     * 企业管理费
     */
    public void setEnterpriseManageTotal(java.math.BigDecimal enterpriseManageTotal) {
        this.enterpriseManageTotal = enterpriseManageTotal;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfitsTotal() {
        return profitsTotal;
    }

    /**
     * 利润
     */
    public void setProfitsTotal(java.math.BigDecimal profitsTotal) {
        this.profitsTotal = profitsTotal;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 合价（元）
     */
    public java.math.BigDecimal getComprehensiveTotal() {
        return comprehensiveTotal;
    }

    /**
     * 合价（元）
     */
    public void setComprehensiveTotal(java.math.BigDecimal comprehensiveTotal) {
        this.comprehensiveTotal = comprehensiveTotal;
    }
    /**
     * 除税合价
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20220404.033202-49-sources.jar: com/ejianc/business/bedget/vo/SubpackagetotalVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包施工图预算汇总
 * 
 * @author generator
 * 
 */
public class SubpackagetotalVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long contract; // 合同
    private java.lang.String contractName; // 合同名称
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String section; // 区段
    private java.lang.String subtitleCode; // 子目编码
    private java.lang.String subtitleName; // 子目名称
    private java.lang.String subtitleFeature; // 子目特征描述
    private java.math.BigDecimal artificialTotal; // 人工费
    private java.math.BigDecimal materialsTotal; // 材料费
    private java.math.BigDecimal mechanicalTotal; // 机械费
    private java.math.BigDecimal enterpriseManageTotal; // 企业管理费
    private java.math.BigDecimal profitsTotal; // 利润
    private java.math.BigDecimal feesTotal; // 规费
    private java.math.BigDecimal taxTotal; // 税金
    private java.math.BigDecimal comprehensiveTotal; // 合价（元）
    private java.math.BigDecimal excludingTaxTotal; // 除税合价
    private java.math.BigDecimal includingTaxTotal; // 含税合价

    private java.util.Date snapShotTime; //快照保存时间
    private java.lang.String reportId; //报表ID
    private java.lang.String snapShotVersion; //快照版本

    private java.lang.Integer pageIndex;
    private java.lang.Integer pageSize;
    private java.lang.String sort;

    private java.lang.String showSnapShotTime;

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getPageIndex() {
        return pageIndex;
    }

    public void setPageIndex(Integer pageIndex) {
        this.pageIndex = pageIndex;
    }

    public Date getSnapShotTime() {
        return snapShotTime;
    }

    public void setSnapShotTime(Date snapShotTime) {
        this.snapShotTime = snapShotTime;
    }

    public String getReportId() {
        return reportId;
    }

    public void setReportId(String reportId) {
        this.reportId = reportId;
    }

    public String getSnapShotVersion() {
        return snapShotVersion;
    }

    public void setSnapShotVersion(String snapShotVersion) {
        this.snapShotVersion = snapShotVersion;
    }

    public String getShowSnapShotTime() {
        return showSnapShotTime;
    }

    public void setShowSnapShotTime(String showSnapShotTime) {
        this.showSnapShotTime = showSnapShotTime;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 区段
     */
    public java.lang.String getSection() {
        return section;
    }

    /**
     * 区段
     */
    public void setSection(java.lang.String section) {
        this.section = section;
    }
    /**
     * 子目编码
     */
    public java.lang.String getSubtitleCode() {
        return subtitleCode;
    }

    /**
     * 子目编码
     */
    public void setSubtitleCode(java.lang.String subtitleCode) {
        this.subtitleCode = subtitleCode;
    }
    /**
     * 子目名称
     */
    public java.lang.String getSubtitleName() {
        return subtitleName;
    }

    /**
     * 子目名称
     */
    public void setSubtitleName(java.lang.String subtitleName) {
        this.subtitleName = subtitleName;
    }
    /**
     * 子目特征描述
     */
    public java.lang.String getSubtitleFeature() {
        return subtitleFeature;
    }

    /**
     * 子目特征描述
     */
    public void setSubtitleFeature(java.lang.String subtitleFeature) {
        this.subtitleFeature = subtitleFeature;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getArtificialTotal() {
        return artificialTotal;
    }

    /**
     * 人工费
     */
    public void setArtificialTotal(java.math.BigDecimal artificialTotal) {
        this.artificialTotal = artificialTotal;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialsTotal() {
        return materialsTotal;
    }

    /**
     * 材料费
     */
    public void setMaterialsTotal(java.math.BigDecimal materialsTotal) {
        this.materialsTotal = materialsTotal;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalTotal() {
        return mechanicalTotal;
    }

    /**
     * 机械费
     */
    public void setMechanicalTotal(java.math.BigDecimal mechanicalTotal) {
        this.mechanicalTotal = mechanicalTotal;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getEnterpriseManageTotal() {
        return enterpriseManageTotal;
    }

    /**
     * 企业管理费
     */
    public void setEnterpriseManageTotal(java.math.BigDecimal enterpriseManageTotal) {
        this.enterpriseManageTotal = enterpriseManageTotal;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfitsTotal() {
        return profitsTotal;
    }

    /**
     * 利润
     */
    public void setProfitsTotal(java.math.BigDecimal profitsTotal) {
        this.profitsTotal = profitsTotal;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 合价（元）
     */
    public java.math.BigDecimal getComprehensiveTotal() {
        return comprehensiveTotal;
    }

    /**
     * 合价（元）
     */
    public void setComprehensiveTotal(java.math.BigDecimal comprehensiveTotal) {
        this.comprehensiveTotal = comprehensiveTotal;
    }
    /**
     * 除税合价
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    
}
